@@ -55,8 +55,9 @@ def build_grai_metadata_from_node(
 def build_grai_metadata_from_edge(
     current: Edge, version: Literal["v1"] = "v1"
 ) -> base_schemas.GraiEdgeMetadata:
-    data = {"version": version}
-    return base_schemas.GraiEdgeMetadata(**data)
+    return base_schemas.GraiEdgeMetadata({"version": "v1"})
+    # data = {"version": version}
+    # return base_schemas.GraiEdgeMetadata(**data)
 
 
 @multimethod
